#
# spec file for package xdotool
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xdotool
Version:        3.20211022.1
Release:        1.7
Summary:        Fake keyboard/mouse input
License:        BSD-3-Clause
Group:          System/X11/Utilities
URL:            https://www.semicomplete.com/projects/xdotool/
Source:         https://github.com/jordansissel/xdotool/releases/download/v%{version}/%{name}-%{version}.tar.gz
BuildRequires:  gcc-c++
BuildRequires:  make
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xinerama)
BuildRequires:  pkgconfig(xkbcommon)
BuildRequires:  pkgconfig(xtst)

%description
This tool lets you programatically (or manually) simulate keyboard input and
mouse activity, move and resize windows, etc. It does this using X11's XTEST
extension and other Xlib functions.

%package devel
Summary:        Development and Library files
Group:          Development/Libraries/X11
Requires:       %{name} = %{version}
Requires:       pkgconfig(x11)

%description devel
This tool lets you programatically (or manually) simulate keyboard input and
mouse activity, move and resize windows, etc. It does this using X11's XTEST
extension and other Xlib functions.

Library and Header files for %{name}

%prep
%setup -q

%build
# Fix file permissions
chmod 0644 examples/ffsp.sh
export WARNFLAGS="%{optflags}"
make %{?_smp_mflags}

%install
%make_install \
    PREFIX=%{_prefix} \
    INSTALLLIB=%{_libdir} \
    INSTALLMAN=%{_mandir} \

chmod 0644 examples/*

%post -p /sbin/ldconfig
%post devel -p /sbin/ldconfig
%postun -p /sbin/ldconfig
%postun devel -p /sbin/ldconfig

%files
%{_bindir}/%{name}
%doc CHANGELIST COPYRIGHT README.md
%doc examples
%{_mandir}/man1/%{name}.1%{ext_man}
%{_libdir}/libxdo.so.*

%files devel
%attr(0644,root,root) %{_includedir}/*.h
%{_libdir}/libxdo.so
%{_libdir}/pkgconfig/libxdo.pc

%changelog
* Tue Jan  4 2022 Dirk Müller <dmueller@suse.com>
- update to 3.2021022.1:
  * Fix a bug causing `make create-package-deb` to fail. (#362)
  * Revert XWayland detection. Some parts of xdotool do not work under
    XWayland. However, many features *do* work on XWayland, and rejecting
    XWayland caused problems for several
    folks who were otherwise happily using xdotool under Wayland/XWayland. (#346, #355)
* Sat Oct 16 2021 Dirk Müller <dmueller@suse.com>
- update to 3.20210903.1:
  * xdotool and libxdo will now reject if it is running under Wayland/XWayland.
    If XWayland is detected, the program will fail. This is because XWayland
    doesn't allow xdotool or libxdo to work correctly. (#342, Jordan Sissel)
  * New command `windowstate` which can be used to modify properties of windows.
    For example, to full-screen the current window, use:
    xdotool getactivewindow windowstate --add FULLSCREEN
  * New command `windowquit`  which is used to ask the windowed application to
    terminate.
  * New command `getwindowclassname` to print the window's class name.
  * When sending keystrokes, `enter` and `return` now are synonyms for the
    `Return` key symbol
  * getmouselocation now updates the window stack with the window the cursor is
    currently over.
  * search command now supports searching by window role with `--role` flag
  * search command should now no longer report BadWindow errors
  * get_window_location now reports correct value
  * Uppercase Latin-1/Basic Latin are now typed correctly
  * Document the regular expressions (POSIX Extended) supported by xdotool
  * Use the default X11 Screen instead of assuming 0
  * Wrap header files with `extern "C"` to enable easier C++ use of libxdo.
  * Install pkgconfig file when running `make install`
  * Set permissions correctly when installing `xdo.h`
  * Fix memory leak
  * Fixed some documentation typos
  * Fix all compiler warnings during `make`
- drop xdotool-2.2012-reproducible.patch, remove-dead-function.patch (upstream)
* Sun Feb 18 2018 avindra@opensuse.org
- update to 3.20160805.1
  * Fix release tool problem. cflags.sh was missing from the
    previous two releases.
  * `make test-package-build` now works correctly on Fedora and OSX
- includes 3.20160804.2
  * Fix some bugs in the Makefile
- includes 3.20160804.1
  * Fix memory leaks in window search and charcode map lookups
  * xdotool selectwindow (xdo_select_window_with_click) now only
    selects the window if mouse button 1 is pressed. Any other
    buttons will cause this selection to be aborted.
  * Fix bug where `xdotool click` with --clearmodifiers can
    sometimes leave stuck keys or mouse buttons.
  * windowmove now supports coordinates as a percentage of screen
    size. For example, a move to 50%% 50%% would move the window
    such that the top-left corner of the window is in the center
    of the screen.
  * Typing commands (key and type) will now try to use XTEST
    instead of XSendEvent in a special circumstance. If the window
    id given (by window stack or the --window flag) is the currenly
    focused window, key sequences will be sent using XTEST.
  * getmouselocation, getwindowgeometry, and search commands: now
    supports --shell and --prefix for having stdout be consumable by
    bash or similar shells.
  * xdotool scripts such as running via `xdotool -` will now execute
    commands as lines of input are read. The previous behavior
    waited until stdin closed before executing anything.
- includes 3.20150503 ()
  * Fix sending wrong keys when using multiple keyboard layouts
  * Add --repeat and --repeat-delay to allow repetition of a key
    sequence
  * Fix handling of empty files in type command
  * consume regexp argument only if present.
  * update URLs to Github
  * Changes determined via:
    https://github.com/jordansissel/xdotool/compare/65cb0b1...v3.20150503.1
  with an optional delay in between each full sequence.
- drop _service file in favor of github release tarball
- use https for site
- cleanup with spec-cleaner
- add remove-dead-function.patch
  * removes reference to function in header file that was removed
* Thu Jul 20 2017 bwiedemann@suse.com
- Add xdotool-2.2012-reproducible.patch to override build date
  to fix build-compare (boo#1047218)
* Sat Nov  1 2014 crrodriguez@opensuse.org
-  Switch to individual pkgconfig() build requires
  instead of using metapackage xorg-x11-devel
- "as-needed" build works, remove SUSE_ASNEEDED workaround.
- xdotool-devel requires pkgconfig(x11)
* Fri Mar  8 2013 aspiers@suse.com
- update to github master @ e0a3e8fb
  + don't try to access xdo until after we verify it's not null. (#18, reported by zarelit)
  + mark swedish and danish symbol typing as known-broken, allow skipping them by setting $SKIP_KNOWN_BROKEN_TESTS
  + provide a way to override which specific test combinations are run
  + create a way to build xdotool without setting rpath (see e.g. https://wiki.debian.org/RpathIssue)
  + include the CPPFLAGS variable for C preprocessor flags
  + Avoid unnecessary double linking
  + bump major version due to API overhaul (including function name normalization)
  + constify display argument in xdo_new() since it will not be modified.
  + allow xdo_free(NULL) without segfaults
* Fri Oct 26 2012 aspiers@suse.com
- add disabled source service and update to github master @ 118979c5
  + Don't translate a window's location if its parent is the root.
  + Fixed merge conflict
  + Fixed an error in xdo_get_window_property
  + Merge miss
  + Unified naming convention for all functions of the API
  + Changed the behaviour of xdo_get_window_property
  + Remove xdo_version.h when cleaning
  + Removed all signed/unsigned conflicts
  + Changed XKeycodeToKeysym to XkbKeycodeToKeysym to get rid of compilation warnings
  + Changed name on xdo_getwinprop() to xdo_window_get_property()
  + Fixed some minor compilation warnings
  + Replaced xdo_get_active_modifiers with xdo_active_keys_to_keycode_list
  + Fix another C++ reserved word issue. Reported in http://bugs.debian.org/cgi-bin/bugreport.cgi?bug=663007
  + add '--file' argument for the type command
  + don't emit 'findclient' messages
  + Hack linker rpath to solve problem of /usr/local/lib (or elsewhere) not being in the run-time linker path (see ldd, etc).
  + abort if we're using a shell that probably won't work
  + fix librt linking on GNU Hurd
  + drop isatty for good (not sure why it was still here). This fixes the 'test_script' test when stdin is /dev/null. Patch by Daniel Kahn Gillmor.
  + add kfreebsd patch from Daniel Kahn Gillmor
  + add todos
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Thu Jan  6 2011 malcolmlewis@opensuse.org
- New version (Refer CHANGELIST)
- Drop asneeded patch
- Add man page patch
  http://code.google.com/p/semicomplete/issues/detail?id=46
- Update/Clean spec file
- Add devel package
* Wed Aug 19 2009 meissner@suse.de
- fixed build with asneeded
* Sun Apr  5 2009 mhrusecky@suse.cz
- First version of package (20090330)
